@@ -1,10 +1,8 @@
 import os
-import glob
 import pathlib
 from urllib.parse import urljoin
 from html import escape
 from base64 import b64encode
-from functools import reduce
 
 from filetype import image_match, video_match, audio_match
 import streamlit as st
@@ -104,7 +102,7 @@ def _get_file_info(root, path):
     return info
 
 
-def st_file_browser(path: str, *, show_preview=True, show_preview_top=False,
+def streamlit_file_browser(path: str, *, show_preview=True, show_preview_top=False,
         glob_pattern='*',
         show_choose_file=False, show_download_file=True, artifacts_site=None, key=None):
     root = pathlib.Path(os.path.abspath(path))
@@ -131,13 +129,13 @@ def st_file_browser(path: str, *, show_preview=True, show_preview_top=False,
 
 if _DEVELOP_MODE:
     st.header('Default Options')
-    event = st_file_browser("example_artifacts", key='A')
+    event = streamlit_file_browser("example_artifacts", key='A')
     st.write(event)
 
     st.header('With Artifacts Server, Allow choose file, disable download')
-    event = st_file_browser("example_artifacts", artifacts_site="http://localhost:1024", show_choose_file=True, show_download_file=False, key='B')
+    event = streamlit_file_browser("example_artifacts", artifacts_site="http://localhost:1024", show_choose_file=True, show_download_file=False, key='B')
     st.write(event)
 
     st.header('Show only molecule files')
-    event = st_file_browser("example_artifacts", artifacts_site="http://localhost:1024", show_choose_file=True, show_download_file=False, glob_pattern='molecule/*', key='C')
+    event = streamlit_file_browser("example_artifacts", artifacts_site="http://localhost:1024", show_choose_file=True, show_download_file=False, glob_pattern='molecule/*', key='C')
     st.write(event)
\ No newline at end of file
